@@ -1,3 +1,5 @@
+if (.Platform$OS.type != "windows") {
+
 library(lme4)
 library(testthat)
 
@@ -104,3 +106,4 @@ expect_equal(var(sumFun(g3)),0)
 ## (lowered tolerance to pass checks on my machine -- SCW)
 expect_equal(sigma(g0)^2, 0.4888248, tolerance=1e-4)
 
+} ## skip on windows (for speed)
