@@ -1,9 +1,7 @@
-library("testthat")
-library("lme4")
 testLevel <- if (nzchar(s <- Sys.getenv("LME4_TEST_LEVEL"))) as.numeric(s) else 1
 
 if (testLevel>1) {
-context("glmer.nb")
+#context("glmer.nb")
 test_that("basic", {
    set.seed(101)
    dd <- expand.grid(f1 = factor(1:3),
@@ -69,14 +67,14 @@ test_that("basic", {
 })
 
 if (requireNamespace("merDeriv")) {
-    testthat("summary not broken by merDeriv", {
+    test_that("summary not broken by merDeriv", {
         library(merDeriv)
         data(Arabidopsis)
         mod <- glmer.nb(total.fruits~status+nutrient+(1|gen), data=Arabidopsis)
         ## trivial test of existence/non-failure ...
         expect_is(summary(mod), "summary.merMod")
         ## may? expose other problems as S3 methods won't be unloaded properly ...
-        detach("package:merMod")
+        detach("package:merDeriv")
     })
 }
 
